@@ -17,13 +17,22 @@ from preseem.pushid import generate_pushid
 ConfigType = namedtuple('ConfigType', ())
 ConfigOp = Enum('ConfigOp', 'ADD DEL')
 
+
 class ConfigClient(PreseemGrpcClient):
+
     def __init__(self, api_key, host=None, port=None, beta=None):
-        super().__init__(api_key, host or 'config{}.preseem.com'.format('-beta' if beta else ''), port)
+        super().__init__(api_key, host
+                         or 'config{}.preseem.com'.format('-beta' if beta else ''),
+                         port)
 
 
 class ConfigModel(object):
-    def __init__(self, client, company_id=None, all_companies=None, instances_only=None):
+
+    def __init__(self,
+                 client,
+                 company_id=None,
+                 all_companies=None,
+                 instances_only=None):
         """With a regular company-specific API key the model will act on the
            company of the API key.  With an all-companies API key, pass in
            a company_id to act as a specific company, or set all_companies=True
@@ -32,17 +41,17 @@ class ConfigModel(object):
            and it calls back with (company_id, old, new) instead of the regular
            callback which just calls (old, new)."""
         self._client = client
-        self.company_id = company_id   # used for multi-company keys
-        self._cbk = None               # optional callback for updates
+        self.company_id = company_id  # used for multi-company keys
+        self._cbk = None  # optional callback for updates
         self.all_companies = all_companies
-        self.objs = {}                 # public: current config objects
+        self.objs = {}  # public: current config objects
         self._sub_task = None  # Instance subscription
         self._sub_lock = asyncio.Lock()
         self._cfg_syn = None
         self._loaded = asyncio.Condition()
         self.instances_only = instances_only
 
-        self.instances = {}   # current supported instances: {company -> {(type, id)}}
+        self.instances = {}  # current supported instances: {company -> {(type, id)}}
         self._sub_tasks = {}  # per-instance subscription state: (task, future)
 
         self._cfg_types = {}
@@ -54,12 +63,16 @@ class ConfigModel(object):
             for field, fd in ct.pb_type.DESCRIPTOR.fields_by_name.items():
                 if fd.message_type:
                     # This is a nested message type.
-                    self._nested_types[fd] = namedtuple(field, [x.name for x in fd.message_type.fields])
+                    self._nested_types[fd] = namedtuple(
+                        field, [x.name for x in fd.message_type.fields])
             nt = namedtuple(ct.name, ct.pb_type.DESCRIPTOR.fields_by_name)
             self._cfg_types[ct.name.replace('_', '-')] = nt
             self._type_map[nt] = ty
             self._type_nt[ty] = nt
-            self._type_field_is_list[ty] = {fd.name: fd.label == FieldDescriptor.LABEL_REPEATED for fd in ct.pb_type.DESCRIPTOR.fields}
+            self._type_field_is_list[ty] = {
+                fd.name: fd.label == FieldDescriptor.LABEL_REPEATED
+                for fd in ct.pb_type.DESCRIPTOR.fields
+            }
 
     def _pb(self, obj, id_prefix=None):
         """convert a config ojbect to a protobuf"""
@@ -90,12 +103,23 @@ class ConfigModel(object):
             except AttributeError:
                 extra = {}
             except json.JSONDecodeError:
-                logging.warning('Bad JSON in extra field for %s: "%s"', config_type, pb.extra)
+                logging.warning('Bad JSON in extra field for %s: "%s"', config_type,
+                                pb.extra)
             if not isinstance(extra, dict):
-                logging.warning('extra field is not a dict for %s: "%s"'.format(config_type, pb.extra))
-        nested_fields = {x.name: x for x in pb.DESCRIPTOR.fields if x in self._nested_types}
+                logging.warning('extra field is not a dict for %s: "%s"'.format(
+                    config_type, pb.extra))
+        nested_fields = {
+            x.name: x
+            for x in pb.DESCRIPTOR.fields if x in self._nested_types
+        }
         field_is_list = self._type_field_is_list[config_type]
-        return nt(*[list(getattr(pb, f, None)) if field_is_list.get(f) else {x.name: getattr(getattr(pb, f), x.name) for x in nested_fields[f].message_type.fields} if f in nested_fields else getattr(pb, f, None) if f != 'extra' else extra for f in nt._fields])
+        return nt(*[
+            list(getattr(pb, f, None)) if field_is_list.get(f) else {
+                x.name: getattr(getattr(pb, f), x.name)
+                for x in nested_fields[f].message_type.fields
+            } if f in nested_fields else getattr(pb, f, None) if f != 'extra' else extra
+            for f in nt._fields
+        ])
 
     def close(self):
         self._client.close_subscriptions()
@@ -124,7 +148,8 @@ class ConfigModel(object):
     def get_default(self, name):
         """Return an "empty" config object for the named config type."""
         nt = self.get_type(name)
-        return self._pb_to_nt(self._type_map[nt], self._pb(nt(*[None for _ in nt._fields])))
+        return self._pb_to_nt(self._type_map[nt],
+                              self._pb(nt(*[None for _ in nt._fields])))
 
     async def delete(self, obj, company_id=None):
         """Delete a configuration object."""
@@ -132,7 +157,8 @@ class ConfigModel(object):
         if config_type is None:
             raise ValueError(f'Set was passed an unknown config class "{type(obj)}"')
         ct = self._client.config_types[config_type]
-        r = await self._client.del_config(config_type, obj.id, company_id or self.company_id)
+        r = await self._client.del_config(config_type, obj.id, company_id
+                                          or self.company_id)
         if not r:
             raise RuntimeError('Failed to delete config instance "{}"'.format(obj.id))
 
@@ -141,16 +167,20 @@ class ConfigModel(object):
         loop = asyncio.get_event_loop()
         fut = loop.create_future()
         result = []
+
         async def cbk(msg, syn=False):
             if msg.event_type == company_configs_pb2.CompanyConfigEvent.LOADED:
                 fut.set_result(True)
             else:
                 try:
-                    r = await self._client.get_config(msg.config_type, msg.config_id, msg.company_id)
+                    r = await self._client.get_config(msg.config_type, msg.config_id,
+                                                      msg.company_id)
                     result.append(self._pb_to_nt(msg.config_type, r))
                 except ValueError:
                     pass  # we don't know about this type, skip it
-        cor = self._client.sub_company_configs(cbk, company_id=self.company_id,
+
+        cor = self._client.sub_company_configs(cbk,
+                                               company_id=self.company_id,
                                                subscribe_all=self.all_companies)
         task = loop.create_task(cor)
         try:
@@ -163,7 +193,8 @@ class ConfigModel(object):
         """Set a configuration object."""
         config_type = self._type_map.get(type(obj))
         pb = self._pb(obj, id_prefix=id_prefix)
-        r = await self._client.set_config(config_type, pb, company_id or self.company_id)
+        r = await self._client.set_config(config_type, pb, company_id
+                                          or self.company_id)
         if not r:
             raise RuntimeException('Failed to set config instance "{}"'.format(obj))
         return obj._replace(id=pb.id)
@@ -191,7 +222,8 @@ class ConfigModel(object):
                 for company_id, instances in self.instances.items():
                     for config_type, config_id in instances:
                         try:
-                            await self._cbk(ConfigOp.ADD, company_id, config_type, config_id)
+                            await self._cbk(ConfigOp.ADD, company_id, config_type,
+                                            config_id)
                         except asyncio.CancelledError:
                             raise
                         except Exception as err:
@@ -224,7 +256,10 @@ class ConfigModel(object):
                     pass
                 else:
                     # subscribe to the instance
-                    task = loop.create_task(self._client.sub_config(msg.config_type, msg.config_id, self.handle_instance_update, msg.company_id))
+                    task = loop.create_task(
+                        self._client.sub_config(msg.config_type, msg.config_id,
+                                                self.handle_instance_update,
+                                                msg.company_id))
                     sub_state = self._sub_tasks[uid] = (task, loop.create_future())
 
         elif msg.event_type == company_configs_pb2.CompanyConfigEvent.DELETE:
@@ -253,7 +288,8 @@ class ConfigModel(object):
                         except asyncio.CancelledError:
                             raise
                         except Exception as err:
-                            logging.warning('Error deleting config "%s": %s', msg.config_id, err)
+                            logging.warning('Error deleting config "%s": %s',
+                                            msg.config_id, err)
 
         if self.instances_only and self._cbk and self._cfg_syn is None:
             # Call a special callback for instance operations only
