@@ -9,9 +9,14 @@ from preseem.util import uint64
 
 FlexMetric = namedtuple('FlexMetric', ('name', 'timestamp', 'labels', 'fields'))
 
+
 class NetworkMetricsClient(PreseemGrpcClient):
+
     def __init__(self, api_key, host=None, port=None, beta=None):
-        super().__init__(api_key, host or 'metrics{}.preseem.com'.format('-beta' if beta else ''), port)
+        super().__init__(
+            api_key, host or 'metrics{}.preseem.com'.format('-beta' if beta else ''),
+            port)
+
 
 class NetworkMetricsModel(object):
     _MAX_MESSAGE_SIZE = 1024 * 1024 * 2  # GRPC max message size is 4K but even getting close seems problematic?
@@ -20,7 +25,7 @@ class NetworkMetricsModel(object):
 
     def __init__(self, client):
         self._client = client
-        self._flex_q = asyncio.Queue(5000) # max size queue to limit memory
+        self._flex_q = asyncio.Queue(5000)  # max size queue to limit memory
         self._flex_task = None
         self._last_q_full = None
         self._drop_count = 0
@@ -38,7 +43,7 @@ class NetworkMetricsModel(object):
             label.value = v
         for f, v in flex.fields.items():
             if v is None:
-                continue    # don't send null values
+                continue  # don't send null values
             tv = obj.fields[str(f)]
             tv.name = str(f)
             ty = type(v)
@@ -53,19 +58,25 @@ class NetworkMetricsModel(object):
                 tv.string_val = v
             elif ty is int:
                 if int.bit_length(v) > 63:
-                    logging.debug("Flex: %s, labels: %s, field: %s's value: %s is bigger than max for INT64", flex.name, flex.labels, f, v)
+                    logging.debug(
+                        "Flex: %s, labels: %s, field: %s's value: %s is bigger than max for INT64",
+                        flex.name, flex.labels, f, v)
                     del obj.fields[str(f)]
                     continue
                 tv.type = metrics_pb2.TV.INT64
                 tv.int64_val = v
             elif ty is uint64:
-                #STM-4895 - influxdb/big-query doesn't support uint64 therefore number bit length equals to or bigger than 64 are filtered 
+                #STM-4895 - influxdb/big-query doesn't support uint64 therefore number bit length equals to or bigger than 64 are filtered
                 if int.bit_length(v) >= 64:
-                    logging.debug("Flex: %s, labels: %s, field: %s's value: %s is bigger than max for UINT64", flex.name, flex.labels, f, v)
+                    logging.debug(
+                        "Flex: %s, labels: %s, field: %s's value: %s is bigger than max for UINT64",
+                        flex.name, flex.labels, f, v)
                     del obj.fields[str(f)]
                     continue
                 if int(v) < 0:
-                    logging.debug("Flex: %s, labels: %s, field: %s's value: %s cannot be negative for UINT64", flex.name, flex.labels, f, v)
+                    logging.debug(
+                        "Flex: %s, labels: %s, field: %s's value: %s cannot be negative for UINT64",
+                        flex.name, flex.labels, f, v)
                     del obj.fields[str(f)]
                     continue
                 tv.type = metrics_pb2.TV.UINT64
@@ -105,7 +116,8 @@ class NetworkMetricsModel(object):
                             pbs = buf
                             buf = None
                         else:
-                            pbs = await asyncio.wait_for(self._flex_q.get(), t - loop.time())
+                            pbs = await asyncio.wait_for(self._flex_q.get(),
+                                                         t - loop.time())
                             self._flex_q.task_done()
                         i = 0
                         for i, pb in enumerate(pbs):
@@ -153,7 +165,8 @@ class NetworkMetricsModel(object):
             return
 
         if not self._flex_task:
-            self._flex_task = asyncio.get_event_loop().create_task(self._service_flex_queue())
+            self._flex_task = asyncio.get_event_loop().create_task(
+                self._service_flex_queue())
         try:
             self._flex_q.put_nowait([self._flex_pb(f) for f in flexes])
         except asyncio.QueueFull:  # send queue is full, drop the request
